#!/bin/bash
currdir=`pwd`
http=http
port=8080
passk=""
SSL=""

usage()
{
    if [ -n "$1" ] ; then
        echo "ERROR: $1"
        echo
    fi

    cat <<EOF
Usage:
    $ME [options]

      <AmbariAdminUserName>  AmbariAdminUserName     Specify Ambari Server Admin User Account
      <SSLENABLED>           SSLENABLED              Optional: Pass the value SSL if Ambari Server is SSL enabled
      <SSLPORT>              SSLPORT                 Optional: Specify Ambari Server SSL port (default port is 8443)

EOF
    exit 1
}


if [ ! -z "$2" ]
then
    http=https
    port=8443
    passk=-k
    SSL=-s
    if [ ! -z "$3" ]
    then
         port=$3
    fi
fi

if [[ $# -lt 1 ]]
then
    echo "The install_hdatplugins.sh script requires an argument: <ambariAdminUsername>."
    usage
    exit

fi

echo "Enter the Ambari admin password."
read -s password
sudo -n true
if [ $? -ne 0 ]
   then
   echo "You do not have root privileges to execute this script. Re-run the script with a root or password-less sudo account."
   exit 1
fi

clusterName=`sudo curl $passk --silent -u $1:$password -H "X-Requested-By:ambari" -X GET $http://localhost:$port/api/v1/clusters|grep cluster_name|cut -d ":" -f 2|cut -d '"' -f 2`
if [[ ! -f $currdir/hdatplugins.gz ]]
then
         echo "HDATPLUGINS installer file hdatplugins.gz not present in current folder $currdir."

         exit
fi
version=2.0.6
if [[ -d /var/lib/ambari-server/resources/stacks/HDP/3.0/services/ ]]
then
       echo "The HDP version 2.7 detected"
       version=3.0
fi

if [[ ! -f $currdir/stacks.gz ]]
then
         echo "HDATPLUGINS Stack artifacts stacks.gz not found in either the user home directory or /tmp directory."
         exit
fi

if [[ ! -d /var/lib/ambari-server/resources ]]
then
        echo "The Ambari server not found on this machine."
        exit
fi

if [[ ! -d /var/lib/ambari-server/resources/stacks/HDP/$version/services/ ]]
then 
       echo "The HDP version $version does not exist on the machine."
       exit 
fi

if [[ ! -d /var/lib/ambari-server/resources/stacks/HDP/$version/services/HDATPLUGINS ]]
then
	sudo tar xvf $currdir/stacks.gz -C /var/lib/ambari-server/resources/stacks/HDP/$version/services/
	if [ $? -ne 0 ]
	then
		echo "Failed to extract HDATPLUGINS  stack file."
		exit
	fi
fi

if [[ ! -f /var/lib/ambari-server/resources/stacks/HDP/$version/services/HDATPLUGINS/version ]]
then 
	echo "The version file for HDATPLUGINS does not exist."
	exit
fi

enterversion=`cat /var/lib/ambari-server/resources/stacks/HDP/$version/services/HDATPLUGINS/version`
sudo mkdir /var/lib/ambari-server/resources/HDATPLUGINS.$enterversion 2> /dev/null
echo $enterversion
sudo cp -f $currdir/hdatplugins.gz /var/lib/ambari-server/resources/HDATPLUGINS.$enterversion/

response=$(sudo curl $passk --silent --write-out "\n%{http_code}\n" -u $1:$password -H "X-Requested-By:ambari" -X GET  $http://localhost:$port/api/v1/clusters/$clusterName/services/HDATPLUGINS)
echo $response
status_code=$(echo "$response" | sed -n '$p')
html=$(echo "$response" | sed '$d')
echo $html
echo $status_code
	
if [[ $status_code == 200 ]]
then
	hdatpluginversion=`/var/lib/ambari-server/resources/scripts/configs.sh -u $1 -p $password -port $port $SSL get localhost $clusterName hdatplugins_config|grep hdatplugins_allversion|cut -d ":" -f 2|cut -d '"' -f 2` 
	allversions=`/var/lib/ambari-server/resources/scripts/configs.sh -u $1 -p $password -port $port $SSL get localhost $clusterName hdatplugins_config|grep hdatplugins_allversion|cut -d ":" -f 2|cut -d '"' -f 2|tr "," "\n"`
        echo $hdatpluginversion
	activatedversion=`/var/lib/ambari-server/resources/scripts/configs.sh -u $1 -p $password -port $port $SSL get localhost $clusterName hdatplugins_config|grep activated_version|cut -d ":" -f 2|cut -d '"' -f 2`
	echo $activatedversion
	found=0
	for version in $allversions; do
	if [[ "$version" == "$enterversion" ]]
	then
		found=1
	fi
	done
	if [[ $found == 1 ]]
	then
		echo "The specified version was already installed. Enter a different version."
		read enterversion
		sudo mkdir /var/lib/ambari-server/resources/HDATPLUGINS.$enterversion
		sudo cp -f $currdir/hdatplugins.gz /var/lib/ambari-server/resources/HDATPLUGINS.$enterversion/
	fi
	sudo /var/lib/ambari-server/resources/scripts/configs.sh -u $1 -p $password -port $port $SSL set localhost  $clusterName hdatplugins_config activated_version $enterversion >/dev/null
	sudo /var/lib/ambari-server/resources/scripts/configs.sh -u $1 -p $password -port $port $SSL set localhost  $clusterName hdatplugins_config hdatplugins_allversion $hdatpluginversion,$enterversion > /dev/null
	
fi

grep AB /var/lib/ambari-server/resources/stacks/HDP/$version/services/HDATPLUGINS/configuration/hdatplugins_config.xml
if [[ $? == 0 ]]
then
        sudo sed -i s/AB/$enterversion/ /var/lib/ambari-server/resources/stacks/HDP/$version/services/HDATPLUGINS/configuration/hdatplugins_config.xml
fi

if [[ $status_code == 200 ]]
then
	echo "Updating HDATPLUGINS to a later version: $enterversion"
	host=`sudo curl $passk --silent -u  $1:$password -H "X-Requested-By:ambari" -X GET $http://localhost:$port/api/v1/clusters/$clusterName/services/HDATPLUGINS/components/HDATPLUGINS_CLIENT|grep host_name|cut -d ":" -f 2`
	for i in $host; do
		sudo curl $passk --output /tmp/test.log -u $1:$password -H "X-Requested-By:ambari" -i -X POST -d '{"RequestInfo" : {"command" : "update_hdatplugins","context" : "update HDATPLUGINS service"},"Requests/resource_filters": [{"service_name" : "HDATPLUGINS","component_name" : "HDATPLUGINS_CLIENT","hosts" :'$i'}]}' $http://localhost:$port/api/v1/clusters/$clusterName/requests
	        sleep 20
	done
	sleep 20
        exit
	
fi

echo "To complete the install process, the Ambari server needs to be restarted. Press y if you want the script to restart or n if you want to restart manually later."
read response
if [[ $response == "y" || $response == "Y" ]]
then
	sudo /usr/sbin/ambari-server restart
	echo "you can install the HDATPLUGINS stack now from Ambari Server"
else
	echo "Skipped the restarting the Ambari Server."
fi
exit

